# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from marax_server_sdk.configuration import Configuration


class RequestBodyPropertiesProducts(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'quantity': 'float',
        'product_id': 'str',
        'name': 'str',
        'brand': 'str',
        'category': 'str',
        'price': 'float',
        'price_units': 'float',
        'discount': 'float',
        'discount_type': 'str'
    }

    attribute_map = {
        'quantity': 'quantity',
        'product_id': 'product_id',
        'name': 'name',
        'brand': 'brand',
        'category': 'category',
        'price': 'price',
        'price_units': 'priceUnits',
        'discount': 'discount',
        'discount_type': 'discountType'
    }

    def __init__(self, quantity=None, product_id=None, name=None, brand=None, category=None, price=None, price_units=None, discount=None, discount_type=None, local_vars_configuration=None):  # noqa: E501
        """RequestBodyPropertiesProducts - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._quantity = None
        self._product_id = None
        self._name = None
        self._brand = None
        self._category = None
        self._price = None
        self._price_units = None
        self._discount = None
        self._discount_type = None
        self.discriminator = None

        if quantity is not None:
            self.quantity = quantity
        if product_id is not None:
            self.product_id = product_id
        if name is not None:
            self.name = name
        if brand is not None:
            self.brand = brand
        if category is not None:
            self.category = category
        if price is not None:
            self.price = price
        if price_units is not None:
            self.price_units = price_units
        if discount is not None:
            self.discount = discount
        if discount_type is not None:
            self.discount_type = discount_type

    @property
    def quantity(self):
        """Gets the quantity of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The quantity of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this RequestBodyPropertiesProducts.


        :param quantity: The quantity of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: float
        """

        self._quantity = quantity

    @property
    def product_id(self):
        """Gets the product_id of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The product_id of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """Sets the product_id of this RequestBodyPropertiesProducts.


        :param product_id: The product_id of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: str
        """

        self._product_id = product_id

    @property
    def name(self):
        """Gets the name of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The name of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RequestBodyPropertiesProducts.


        :param name: The name of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def brand(self):
        """Gets the brand of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The brand of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this RequestBodyPropertiesProducts.


        :param brand: The brand of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: str
        """

        self._brand = brand

    @property
    def category(self):
        """Gets the category of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The category of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this RequestBodyPropertiesProducts.


        :param category: The category of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def price(self):
        """Gets the price of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The price of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this RequestBodyPropertiesProducts.


        :param price: The price of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def price_units(self):
        """Gets the price_units of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The price_units of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: float
        """
        return self._price_units

    @price_units.setter
    def price_units(self, price_units):
        """Sets the price_units of this RequestBodyPropertiesProducts.


        :param price_units: The price_units of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: float
        """

        self._price_units = price_units

    @property
    def discount(self):
        """Gets the discount of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The discount of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: float
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this RequestBodyPropertiesProducts.


        :param discount: The discount of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: float
        """

        self._discount = discount

    @property
    def discount_type(self):
        """Gets the discount_type of this RequestBodyPropertiesProducts.  # noqa: E501


        :return: The discount_type of this RequestBodyPropertiesProducts.  # noqa: E501
        :rtype: str
        """
        return self._discount_type

    @discount_type.setter
    def discount_type(self, discount_type):
        """Sets the discount_type of this RequestBodyPropertiesProducts.


        :param discount_type: The discount_type of this RequestBodyPropertiesProducts.  # noqa: E501
        :type: str
        """

        self._discount_type = discount_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RequestBodyPropertiesProducts):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RequestBodyPropertiesProducts):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import marax_server_sdk
from marax_server_sdk.models.request_body import RequestBody  # noqa: E501
from marax_server_sdk.rest import ApiException

class TestRequestBody(unittest.TestCase):
    """RequestBody unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RequestBody
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = marax_server_sdk.models.request_body.RequestBody()  # noqa: E501
        if include_optional :
            return RequestBody(
                event = 'ORDER_COMPLETED', 
                properties = marax_server_sdk.models.request_body_properties.RequestBody_properties(
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    marax_id = '0', 
                    client_id = '0', 
                    reward = marax_server_sdk.models.request_body_properties_reward.RequestBody_properties_reward(
                        id = '0', 
                        expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timezone = 'Asia/Kolkata', 
                        promocode = 'SWIGGYIT', 
                        title = 'Flat Rs 100/- off', 
                        body = 'Applicable on all order above', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        type = 'monetory', 
                        ui = 'scratch_card', 
                        handled_by = 'marax', ), 
                    payment_mode = 'cash', 
                    total_cart_price = marax_server_sdk.models.request_body_properties_total_cart_price.RequestBody_properties_totalCartPrice(
                        value = 500, 
                        units = 'rupees', ), 
                    total_discount = marax_server_sdk.models.request_body_properties_total_discount.RequestBody_properties_totalDiscount(
                        value = 100, 
                        type = 'rupees', ), 
                    total_order_price = marax_server_sdk.models.request_body_properties_total_order_price.RequestBody_properties_totalOrderPrice(
                        value = 510.5, 
                        units = 'rupees', ), 
                    products = [
                        marax_server_sdk.models.request_body_properties_products.RequestBody_properties_products(
                            quantity = 2, 
                            product_id = '0', 
                            name = 'Fossil Wrist Watch for Men', 
                            brand = 'Fossil', 
                            category = 'watch', 
                            price = 500, 
                            price_units = 1.337, 
                            discount = 100, 
                            discount_type = 'monetory', )
                        ], 
                    fulfillment = [
                        marax_server_sdk.models.request_body_properties_fulfillment.RequestBody_properties_fulfillment(
                            type = 'surcharge', 
                            price = 10.5, 
                            price_units = 'rupees', 
                            discount = 0, 
                            discount_type = 'monetory', )
                        ], )
            )
        else :
            return RequestBody(
                event = 'ORDER_COMPLETED',
                properties = marax_server_sdk.models.request_body_properties.RequestBody_properties(
                    timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    marax_id = '0', 
                    client_id = '0', 
                    reward = marax_server_sdk.models.request_body_properties_reward.RequestBody_properties_reward(
                        id = '0', 
                        expiry = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timezone = 'Asia/Kolkata', 
                        promocode = 'SWIGGYIT', 
                        title = 'Flat Rs 100/- off', 
                        body = 'Applicable on all order above', 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        type = 'monetory', 
                        ui = 'scratch_card', 
                        handled_by = 'marax', ), 
                    payment_mode = 'cash', 
                    total_cart_price = marax_server_sdk.models.request_body_properties_total_cart_price.RequestBody_properties_totalCartPrice(
                        value = 500, 
                        units = 'rupees', ), 
                    total_discount = marax_server_sdk.models.request_body_properties_total_discount.RequestBody_properties_totalDiscount(
                        value = 100, 
                        type = 'rupees', ), 
                    total_order_price = marax_server_sdk.models.request_body_properties_total_order_price.RequestBody_properties_totalOrderPrice(
                        value = 510.5, 
                        units = 'rupees', ), 
                    products = [
                        marax_server_sdk.models.request_body_properties_products.RequestBody_properties_products(
                            quantity = 2, 
                            product_id = '0', 
                            name = 'Fossil Wrist Watch for Men', 
                            brand = 'Fossil', 
                            category = 'watch', 
                            price = 500, 
                            price_units = 1.337, 
                            discount = 100, 
                            discount_type = 'monetory', )
                        ], 
                    fulfillment = [
                        marax_server_sdk.models.request_body_properties_fulfillment.RequestBody_properties_fulfillment(
                            type = 'surcharge', 
                            price = 10.5, 
                            price_units = 'rupees', 
                            discount = 0, 
                            discount_type = 'monetory', )
                        ], ),
        )

    def testRequestBody(self):
        """Test RequestBody"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    marax-server-sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import marax_server_sdk
from marax_server_sdk.api.reward_api import RewardApi  # noqa: E501
from marax_server_sdk.rest import ApiException


class TestRewardApi(unittest.TestCase):
    """RewardApi unit test stubs"""

    def setUp(self):
        self.api = marax_server_sdk.api.reward_api.RewardApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_process_event(self):
        """Test case for process_event

        Perform reward post-processing  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    marax_server_sdk

    Marax Server SDK to send transactional events from client server to marax server  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: team@marax.ai
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "marax_server_sdk"
VERSION = "0.2.7"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil","cryptography","pyjwt"]
REQUIRES.append("tornado>=4.2,<5")
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=NAME,
    version=VERSION,
    description="marax_server_sdk",
    author="OpenAPI Generator community",
    author_email="team@marax.ai",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "marax_server_sdk"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache-2.0",
    long_description=long_description,
    long_description_content_type='text/markdown'
)
